@@ -3,8 +3,8 @@ from typing import Iterable
 import numpy as np
 
 from cca_zoo.deepmodels import _objectives
-from cca_zoo.deepmodels._dcca import DCCA
 from cca_zoo.models import TCCA
+from ._dcca import DCCA
 
 
 class DTCCA(DCCA):
@@ -23,6 +23,7 @@ class DTCCA(DCCA):
         self, latent_dims: int, encoders=None, r: float = 0, eps: float = 1e-5, **kwargs
     ):
         """
+        Constructor class for DTCCA
 
         :param latent_dims: # latent dimensions
         :param encoders: list of encoder networks
@@ -38,10 +39,10 @@ class DTCCA(DCCA):
             **kwargs
         )
 
-    def post_transform(self, z_list, train=False) -> Iterable[np.ndarray]:
+    def post_transform(self, z, train=False) -> Iterable[np.ndarray]:
         if train:
             self.cca = TCCA(latent_dims=self.latent_dims)
-            z_list = self.cca.fit_transform(z_list)
+            z = self.cca.fit_transform(z)
         else:
-            z_list = self.cca.transform(z_list)
-        return z_list
+            z = self.cca.transform(z)
+        return z
