@@ -6,4 +6,4 @@ from .check_values import (
     _check_parameter_number,
     _check_converged_weights,
 )
-from .plotting import plot_latent_train_test, plot_latent_label, cv_plot
+from .plotting import pairplot_label, pairplot_train_test, tsne_label, cv_plot
